#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-1hUGImAvUZAEucWCi5UU6Z
key:                  coinbase-pro-0.9.3.2-1hUGImAvUZAEucWCi5UU6Z
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  09ecea1cf53f644eb5a2a46c38b276aa
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-1hUGImAvUZAEucWCi5UU6Z
depends:
    HsOpenSSL-0.11.7.9-DsLp9TSiswu8wFdWF66lvD
    aeson-2.2.1.0-28ssJzlQESE12G8XLETNIx
    aeson-casing-0.2.0.0-EW9Q9NTmT5U3xycXFjoBYY
    async-2.2.5-FIWsXw8tceP2d6lj6DHM5i base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-3buMfWsKTbpImpvCk0Pf2w exceptions-0.10.7
    http-api-data-0.6.1-IeYVQxVQYT8EZQeGOZN78a
    http-client-0.7.19-2UeAfN562pLBCSD1YRqnzt
    http-client-tls-0.3.6.4-1xmOGBcWDShBmBSqs3mCxH
    http-streams-0.8.9.9-22Vt2tsOXMo3ATERIHmlD8
    http-types-0.12.4-E7NglevSDUe4aFzTHGY2t7
    io-streams-1.5.2.2-7qh7UHxV5e2AP9OxYgEB7n
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-9YNBV8UGnKyEcMIeWoZU
    servant-0.20.3.0-BMLWNjDRXEf2oW3C7tucBw
    servant-client-0.20.3.0-2Xq4wfZ34RQ4nrPKWZjrrb
    servant-client-core-0.20.3.0-DDFvnlgW4ZXCAGLOF4dU9p
    tasty-1.5.2-LwEXSl8ldkFLRyZHMQwKn1
    tasty-hunit-0.10.2-ClyqywvO9zYLRa2uIpb5f6 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-3RJFsHLNrCLGeTP5lQWRWJ
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    uuid-1.3.16-9HCSfEmPNfB3Ub0NyqmB3Q
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE
    websockets-0.12.7.3-HKeVA7kdJkbIbmVlnRCtWf
    wuss-2.0.1.6-CRIh2EUnVRYBNOfBrowzmw

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

